# 数据库公共方法库(Database Common Method Library)

## 1. 简介(abstract)

```
数据库公共方法库目前包括对MySQL，MongoDB，Redis，PostgreSQL四种数据库的增删改查，具体的使用说明和使用示例可以查看类或者方法的说明，如果有任何bug或建议，请联系我进行修改完善。
The public database method library currently includes CRUD operations (Create, Read, Update, Delete) for four types of databases: MySQL, MongoDB, Redis, and PostgreSQL. For specific usage instructions and examples, please refer to the class or method descriptions. If you encounter any bugs or have suggestions, please do not hesitate to contact me for improvements and modifications.
```

## 2.作者及联系方式

```
# ***************************************************************
# Maintainers:
#     chuntong pan <panzhang1314@gmail.com>
# Date:
#     2023.8
# ***************************************************************
```

